{% extends "site_base.html" %}
{% load thumbnail %}
{% load account_tags %}
{% user_display user as user_display %}
{% load gravatar %}

{% block "metas" %}
    <title>{{ title }} - {{ settings.SITE_TITLE }}</title>
    <meta name="description" content="{{ settings.SITE_DESCRIPTION }}" />
{% endblock "metas" %}

{% block "breadcrumbs" %}
{% endblock "breadcrumbs" %}

{% block "content" %}
  {% if user.is_authenticated %}
    <section id="forum">

      <ul class="breadcrumb">
        <li><i class="icon-home"></i> <a href="{% url app_forum-forum-index %}">{{ _('Index') }}</a> <span class="divider">/</span></li>
        <li><i class="icon-plus-sign"></i> {{ _('User Profile') }}</li>
      </ul>

      {% include "rforum/elements/forum-top.html" %}

      <div class="forum">
        <table class="table table-bordered">
          <thead>
            <tr>
              <th colspan="2"><h3></h3></th>
          </thead>
          <tbody>
            <tr>
              <td>
                <div class="offset2">
                <form action="" method="POST" class="form-horizontal" enctype="multipart/form-data">
                  {% csrf_token %}
                  {{ form.as_p }}
                  <input type="submit" class="btn" value="submit" />
                </form>
                </div>
              </td>
              <td style="text-align: center; width: 200px;">
                {% include "rforum/elements/forum-userdetail.html" %}
              </td>
            </tr>
          </tbody>
        </table>
      </div>

      {% include "rforum/elements/forum-bottom.html" %}

    </section>
  {% endif %}
{% endblock "content" %}
