{% extends "site_base.html" %}

{% load url from future %}
{% load i18n %}

{% block metas %}
    <title>{{ _('Signup') }} - {{ settings.SITE_TITLE }}</title>
{% endblock %}

{% block breadcrumbs %}
{% endblock %}

{% block content %}
<section id="forum">
  {% include "rforum/elements/forum-top.html" %}

  <ul class="breadcrumb">
	<li><i class="icon-user"></i> {{ _('Register') }}</li>
  </ul>

  {% if user.is_authenticated %}
  {% include "account/snippets/already_logged_in.html" %}
  {% else %}
  <div class="alert alert-info">
  <button type="button" class="close" data-dismiss="alert">×</button>
  {% blocktrans %}Already have an account? Then please <strong><a href="{{ login_url }}">login</a></strong>.{% endblocktrans %}
  </div>
  
  <div class="offset3">
  <form class="signup form-horizontal" id="signup_form" method="post" action="{% url 'account_signup' %}">
	<div class="control-group">
    {% csrf_token %}
    {{ form.as_table }}
    {% if redirect_field_value %}
      <input type="hidden" name="{{ redirect_field_name }}" value="{{ redirect_field_value }}" />
    {% endif %}
    <button type="submit" class="btn btn-info">{{ _('Register') }} &raquo;</button>
  </form>
  </div>
  {% endif %}

</section>
{% endblock %}


