{% extends "site_base.html" %}

{% load i18n %}
{% load account_tags %}

{% block metas %}
    <title>{{ _('Password Reset') }} - {{ settings.SITE_TITLE }}</title>
{% endblock %}

{% block breadcrumbs %}
{% endblock %}

{% block content %}
<section id="forum">
  {% include "rforum/elements/forum-top.html" %}

  <ul class="breadcrumb">
	<li><i class="icon-user"></i> {{ _('Password Reset') }}</li>
  </ul>

    {% if user.is_authenticated %}
    {% include "account/snippets/already_logged_in.html" %}
    {% endif %}
    
    <p>{% trans "Forgotten your password? Enter your e-mail address below, and we'll send you an e-mail allowing you to reset it. " %}{% blocktrans %}If you have any trouble resetting your password, contact us at <a href="mailto:{{ settings.SITE_CONTACT_EMAIL }}">{{ settings.SITE_CONTACT_EMAIL }}</a>.{% endblocktrans %}</p>
    
    <form method="POST" action="" class="password_reset offset3 form-horizontal">
        {% csrf_token %}
        {{ password_reset_form.as_p }}
        <input type="submit" value="{% trans "Reset My Password" %}"
        class="btn btn-info" />
    </form>

</section>

<script>
  $("#id_email").focus();
</script>
{% endblock %}
