{% load account_tags %}
{% user_display user as user_display %}

  <div class="forum-top">
    <ul>
      {% if not user.is_authenticated %}
      <li><a href="{% url account_signup %}" class="btn">{{ _('Register') }}</a></li>
      <li><a href="{% url account_login %}" class="btn">{{ _('Login') }}</a></li>
      {% endif %}
      {% if user.is_authenticated %}
      <li><a href="{% url app_rauthall-profile %}"class="btn"><i class="icon-user"></i> {{ user_display }}</a></li>
      <li><a href="{% url account_logout %}" class="btn">{{ _('Logout') }}</a></li>
      {% endif %}
    </ul>

  </div>
