{% extends "site_base.html" %}

{% load url from future %}
{% load i18n %}

{% block metas %}
    <title>{{ _('Verify Your E-mail Address') }} - {{ settings.SITE_TITLE }}</title>
{% endblock %}

{% block breadcrumbs %}
{% endblock %}

{% block content %}
<section id="forum">
  {% include "rforum/elements/forum-top.html" %}

  <ul class="breadcrumb">
	<li><i class="icon-user"></i> {{ _('Verify Your E-mail Address') }}</li>
  </ul>

    <p>{% blocktrans %}We have sent you an e-mail to <b>{{ email }}</b> for verification. Follow the link provided to finalize the signup process. If you do not receive it within a few minutes, contact us at <a href="mailto:{{ settings.SITE_CONTACT_EMAIL }}">{{ settings.SITE_CONTACT_EMAIL }}</a>.{% endblocktrans %}</p>

</section>
{% endblock %}
