{% extends "site_base.html" %}
{% load thumbnail %}
{% load account_tags %}
{% user_display user as user_display %}
{% load gravatar %}
{% load i18n %}
{% load ranks %}

{% block "metas" %}
    <title>{{ title }} - {{ settings.SITE_TITLE }}</title>
    <meta name="description" content="{{ settings.SITE_DESCRIPTION }}" />
{% endblock "metas" %}

{% block "breadcrumbs" %}
      <ul class="breadcrumb">
        <li><i class="icon-home"></i> <a href="{% url app_forum-forum-index %}">{{ _('Forum') }}</a> <span class="divider">/</span></li>
        <li><i class="icon-plus-sign"></i> {% blocktrans %}  {{ myuser }}'s profile {% endblocktrans %}</li>
      </ul>
{% endblock "breadcrumbs" %}

{% block "content" %}
    <section id="forum">

      {% include "rforum/elements/forum-top.html" %}

      <div class="forum">
        <table class="table table-bordered">
          <thead>
            <tr>
              <th colspan="2"><h3></h3></th>
          </thead>
          <tbody>
            <tr>
              <td>
                <div class="offset2">
                  <div style="margin: 20px 0;">
                    <div class="clearfix" style="margin-bottom: 10px">
                      <div class="label" style="width: 100px; float: left; padding: 5px;">{{ _('Username') }}</div> <div style="margin-left: 120px; margin-top: 2px;">{{ userprofile.user.username }}</div>
                    </div>
                    <div class="clearfix" style="margin-bottom: 10px">
                      <div class="label" style="width: 100px; float: left; padding: 5px;">{{ _('Rank') }}</div> <div style="margin-left: 120px; margin-top: 2px;">{% rank userprofile.user.username userprofile.user.posts.count %}</div>
                    </div>
                    <div class="clearfix" style="margin-bottom: 10px">
                      <div class="label" style="width: 100px; float: left; padding: 5px;">{{ _('Num.posts') }}</div> <div style="margin-left: 120px; margin-top: 2px;">{{ userprofile.user.posts.count }}</div>
                    </div>
                    <div class="clearfix" style="margin-bottom: 10px">
                      <div class="label" style="width: 100px; float: left; padding: 5px;">{{ _('Last login') }}</div> <div style="margin-left: 120px; margin-top: 2px;">{{ userprofile.user.last_login }}</div>
                    </div>
                    <div class="clearfix" style="margin-bottom: 10px">
                      <div class="label" style="width: 100px; float: left; padding: 5px;">{{ _('Date joined') }}</div> <div style="margin-left: 120px; margin-top: 2px;">{{ userprofile.user.date_joined }}</div>
                    </div>
                    {% if userprofile.twitter %}
                    <div class="clearfix" style="margin-bottom: 10px">
                      <div class="label label-info" style="width: 100px; float: left; padding: 5px;">{{ _('Twitter') }}</div> <div style="margin-left: 120px; margin-top: 2px;"><a href="http://www.twitter.com/{{ userprofile.twitter }}">{{ userprofile.twitter }}</a></div>
                    </div>
                    {% endif %}
                    {% if userprofile.signature %}
                    <div class="clearfix" style="margin-bottom: 10px">
                      <div class="label" style="width: 100px; float: left; padding: 5px;">{{ _('Firma') }}</div> <div style="margin-left: 120px; margin-top: 2px;">{{ userprofile.signature }}</div>
                    </div>
                    {% endif %}
                  </div>
                </div>
              </td>
              <td style="text-align: center; width: 200px;">
                {% include "rforum/elements/forum-userdetail.html" %}
              </td>
            </tr>
          </tbody>
        </table>
      </div>

      {% include "rforum/elements/forum-bottom.html" %}

    </section>
{% endblock "content" %}
