<section id="articulos">
    <h1 style="margin-left: 0;">{{ _('Last posts in the forum') }}</h1>
    {% for post in lastposts %}
    <article class="portada">
        <header>
            <div style="float: left"><time datetime="{{ post.date_created|date:"d.m.Y" }}" pubdate="pubdate">{{ post.date_created|date:"d.m.y" }}</time> &#8212;</div>
            <div style="margin-left: 75px;">
              <a href="{% url app_forum-topic-list post.topic.forum.slug post.topic.slug %}#{{ post.id }}">{{ post.topic.title }}</a>
              {{ _('by') }} <a href="" style="font-weight: bold; color: #000">{{ post.user }}</a> {{ _('in') }} "{{ post.topic.forum.title }}"
            </div>
        </header>
    </article>
    {% endfor %}
</section>


